@@ -33,7 +33,7 @@
 #include <X11/keysym.h>
 #include <X11/Xlib.h>
 
-// This code is taken from xset utility from XFree 4.3 (http://www.xfree86.org/)
+// This code is taken from xset utility from XFree 4.3 (https://www.xfree86.org/)
 
 static
 void set_repeatrate(int delay, double rate)
@@ -76,7 +76,9 @@ int set_repeat_mode(TriState keyboardRepeatMode)
 
 void init_keyboard_hardware()
 {
-    KConfigGroup config(KSharedConfig::openConfig( QStringLiteral("kcminputrc") ), "Keyboard");
+	auto inputConfig = KSharedConfig::openConfig( QStringLiteral("kcminputrc") );
+	inputConfig->reparseConfiguration();
+	KConfigGroup config(inputConfig, "Keyboard");
 
 	QString keyRepeatStr = config.readEntry("KeyboardRepeating", TriStateHelper::getString(STATE_ON));
 	TriState keyRepeat = STATE_UNCHANGED;
@@ -100,4 +102,5 @@ void init_keyboard_hardware()
         KModifierKeyInfo keyInfo;
         keyInfo.setKeyLocked(Qt::Key_NumLock, numlockState == STATE_ON);
 	}
+	XFlush(QX11Info::display());
 }
